@@ -1431,7 +1431,7 @@ Flux v5 = {}\n
 Flux v6 = {}\n
 Flux v7 = {}\n\n
 ##########
-            """.format(hw5.v1,hw5.v4,hw5.v5,hw5.v6,hw5.v7)
+            """.format(self.v1,self.v4,self.v5,self.v6,self.v7)
             print(txt)
         
         
@@ -1581,9 +1581,9 @@ Flux v7 = {}\n\n
         print("Concounter=",concounter)
         print("Glucose/v1",self.v1)
         print("Lactate/v4",self.v4)
-        print("v5",self.v5)
-        print("v6",self.v6)
-        print("v7",self.v7)
+        print("Formate/v5",self.v5)
+        print("Acetate/v6",self.v6)
+        print("Ethanol/v7",self.v7)
         print("Nonconform pairs:",noncon)
         print("2v1-v4-v5 = 0 | {} +- {}".format((p1[0]-p2[0]),(p1[1]+p2[1])))
         print("2v1-v4-2v6 = 0 | {} +- {}".format((p1[0]-p3[0]),(p1[1]+p3[1])))
